@@ -21,8 +21,7 @@
 package org.apache.qpid.server.store.berkeleydb.replication;
 
 import static org.apache.qpid.server.store.berkeleydb.EnvironmentFacade.JUL_LOGGER_LEVEL_OVERRIDE;
-import static org.apache.qpid.server.store.berkeleydb.EnvironmentFacade
-        .LOG_HANDLER_CLEANER_PROTECTED_FILES_LIMIT_PROPERTY_NAME;
+import static org.apache.qpid.server.store.berkeleydb.EnvironmentFacade.LOG_HANDLER_CLEANER_PROTECTED_FILES_LIMIT_PROPERTY_NAME;
 import static org.apache.qpid.server.store.berkeleydb.replication.ReplicatedEnvironmentFacade.*;
 import static org.hamcrest.CoreMatchers.equalTo;
 import static org.hamcrest.CoreMatchers.is;
@@ -37,8 +36,8 @@ import static org.junit.Assume.assumeThat;
 import static org.mockito.ArgumentMatchers.any;
 import static org.mockito.ArgumentMatchers.anyBoolean;
 import static org.mockito.ArgumentMatchers.anyInt;
+import static org.mockito.ArgumentMatchers.anyString;
 import static org.mockito.ArgumentMatchers.eq;
-import static org.mockito.ArgumentMatchers.isA;
 import static org.mockito.Mockito.mock;
 import static org.mockito.Mockito.when;
 
@@ -69,6 +68,8 @@ import com.sleepycat.je.DatabaseConfig;
 import com.sleepycat.je.DatabaseEntry;
 import com.sleepycat.je.Durability;
 import com.sleepycat.je.EnvironmentConfig;
+import com.sleepycat.je.LockMode;
+import com.sleepycat.je.OperationStatus;
 import com.sleepycat.je.Transaction;
 import com.sleepycat.je.TransactionConfig;
 import com.sleepycat.je.rep.NoConsistencyRequiredPolicy;
@@ -932,11 +933,8 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         ReplicatedEnvironmentConfiguration configuration =  createReplicatedEnvironmentConfiguration(TEST_NODE_NAME + "_1", node1NodeHostPort, false);
         when(configuration.getHelperNodeName()).thenReturn(TEST_NODE_NAME);
 
-        TestStateChangeListener stateChangeListener = new TestStateChangeListener();
-        ReplicatedEnvironmentFacade secondNode = createReplicatedEnvironmentFacade(TEST_NODE_NAME + "_1",
-                                                                                   stateChangeListener, new NoopReplicationGroupListener(), configuration);
-        assertTrue("Environment was not created", stateChangeListener.awaitForStateChange(State.REPLICA,
-                                                                                          _timeout, TimeUnit.SECONDS));
+        ReplicatedEnvironmentFacade secondNode =
+                createNode(configuration, TEST_NODE_NAME + "_1", State.REPLICA);
         assertEquals("Unexpected state", State.REPLICA.name(), secondNode.getNodeState());
     }
 
@@ -970,9 +968,7 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
     @Test
     public void testNodeRolledback()  throws Exception
     {
-        DatabaseConfig createConfig = new DatabaseConfig();
-        createConfig.setAllowCreate(true);
-        createConfig.setTransactional(true);
+        DatabaseConfig createConfig = createDatabaseConfig();
 
         TestStateChangeListener masterListener = new TestStateChangeListener();
         ReplicatedEnvironmentFacade node1 = addNode(TEST_NODE_NAME, TEST_NODE_HOST_PORT, true, masterListener, new NoopReplicationGroupListener());
@@ -986,12 +982,12 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         Database db = node1.openDatabase("mydb", createConfig);
 
         // Put a record (that will be replicated)
-        putRecord(node1, db, 1, "value1");
+        putRecord(node1, db, 1, "value1", false);
 
         node2.close();
 
         // Put a record (that will be only on node1 as node2 is now offline)
-        putRecord(node1, db, 2, "value2");
+        putRecord(node1, db, 2, "value2", false);
 
         db.close();
 
@@ -1010,7 +1006,7 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
         db = node2.openDatabase("mydb", DatabaseConfig.DEFAULT);
 
         // Do a transaction on node2. The two environments will have diverged
-        putRecord(node2, db, 3, "diverged");
+        putRecord(node2, db, 3, "diverged", false);
 
         LOGGER.debug("RESTARTING " + TEST_NODE_NAME);
         // Now restart node1 and ensure that it realises it needs to rollback before it can rejoin.
@@ -1031,7 +1027,7 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
                    _replicaRolledback.await(_timeout, TimeUnit.SECONDS));
 
         // Finally do one more transaction through the master
-        putRecord(node2, db, 4, "value4");
+        putRecord(node2, db, 4, "value4", false);
         db.close();
 
         LOGGER.debug("CLOSING");
@@ -1196,22 +1192,149 @@ public class ReplicatedEnvironmentFacadeTest extends UnitTestBase
                    masterListener.awaitForStateChange(State.MASTER, _timeout, TimeUnit.SECONDS));
     }
 
-    private void putRecord(final ReplicatedEnvironmentFacade master, final Database db, final int keyValue,
-                           final String dataValue)
+    @Test
+    public void testCommitNoSyncWithCoalescing() throws Exception
     {
-        DatabaseEntry key = new DatabaseEntry();
-        DatabaseEntry data = new DatabaseEntry();
+        final ReplicatedEnvironmentConfiguration node1Config =
+                createReplicatedEnvironmentConfiguration(TEST_NODE_NAME, TEST_NODE_HOST_PORT, true, false);
+        when(node1Config.getFacadeParameter(eq(String.class),
+                                            eq(NO_SYNC_TX_DURABILITY_PROPERTY_NAME),
+                                            anyString())).thenReturn("NO_SYNC,NO_SYNC,NONE");
 
-        TransactionConfig transactionConfig = new TransactionConfig();
-        transactionConfig.setDurability(master.getRealMessageStoreDurability());
-        Transaction txn = master.beginTransaction(transactionConfig);
-        IntegerBinding.intToEntry(keyValue, key);
-        StringBinding.stringToEntry(dataValue, data);
+        final ReplicatedEnvironmentFacade node1 = createNode(node1Config, TEST_NODE_NAME, State.MASTER);
 
-        db.put(txn, key, data);
-        txn.commit();
+        final String replicaNodeHostPort = "localhost:" + _portHelper.getNextAvailable();
+        final String replicaName = TEST_NODE_NAME + 1;
+        final ReplicatedEnvironmentConfiguration node2Config =
+                createReplicatedEnvironmentConfiguration(replicaName, replicaNodeHostPort, false, false);
+        when(node2Config.getFacadeParameter(eq(String.class),
+                                            eq(NO_SYNC_TX_DURABILITY_PROPERTY_NAME),
+                                            anyString())).thenReturn("NO_SYNC,NO_SYNC,NONE");
+        final ReplicatedEnvironmentFacade node2 = createNode(node2Config, replicaName, State.REPLICA);
+
+        try (final Database db = node1.openDatabase("mydb", createDatabaseConfig()))
+        {
+            putRecord(node1, db, 1, "value", true);
+        }
+
+        node2.close();
+        node1.close();
+
+        LOGGER.debug("RESTARTING " + TEST_NODE_NAME);
+        final ReplicatedEnvironmentFacade node1Restarted = createNode(node1Config, TEST_NODE_NAME, State.MASTER);
+        LOGGER.debug("RESTARTING " + replicaName);
+        final ReplicatedEnvironmentFacade node2Restarted = createNode(node2Config, replicaName, State.REPLICA);
+
+        try (final Database db = node1Restarted.openDatabase("mydb", null))
+        {
+            assertEquals("value", getTestKeyValue(db, 1));
+        }
+        node1Restarted.close();
+        node2Restarted.close();
     }
 
+    @Test
+    public void testCommitNoSyncWithoutCoalescing() throws Exception
+    {
+        final ReplicatedEnvironmentConfiguration node1Config =
+                createReplicatedEnvironmentConfiguration(TEST_NODE_NAME, TEST_NODE_HOST_PORT, true, true);
+        when(node1Config.getFacadeParameter(eq(String.class),
+                                            eq(NO_SYNC_TX_DURABILITY_PROPERTY_NAME),
+                                            anyString())).thenReturn("SYNC,NO_SYNC,NONE");
+
+        final ReplicatedEnvironmentFacade node1 = createNode(node1Config, TEST_NODE_NAME, State.MASTER);
+
+        final String replicaNodeHostPort = "localhost:" + _portHelper.getNextAvailable();
+        final String replicaName = TEST_NODE_NAME + 1;
+
+        final ReplicatedEnvironmentConfiguration node2Config =
+                createReplicatedEnvironmentConfiguration(replicaName, replicaNodeHostPort, false, true);
+        when(node2Config.getFacadeParameter(eq(String.class),
+                                            eq(NO_SYNC_TX_DURABILITY_PROPERTY_NAME),
+                                            anyString())).thenReturn("NO_SYNC,NO_SYNC,NONE");
+        final ReplicatedEnvironmentFacade node2 = createNode(node2Config, replicaName, State.REPLICA);
+
+        try (final Database db = node1.openDatabase("mydb", createDatabaseConfig()))
+        {
+            putRecord(node1, db, 1, "value", true);
+        }
+
+        node1.close();
+        node2.close();
+
+        LOGGER.debug("RESTARTING " + TEST_NODE_NAME);
+        final ReplicatedEnvironmentFacade node1Restarted = createNode(node1Config, TEST_NODE_NAME, State.MASTER);
+        LOGGER.debug("RESTARTING " + replicaName);
+        final ReplicatedEnvironmentFacade node2Restarted = createNode(node2Config, replicaName, State.REPLICA);
+
+        try (final Database db = node1Restarted.openDatabase("mydb", null))
+        {
+            assertEquals("value", getTestKeyValue(db, 1));
+        }
+        node1Restarted.close();
+        node2Restarted.close();
+    }
+
+    private ReplicatedEnvironmentFacade createNode(final ReplicatedEnvironmentConfiguration node1Config,
+                                                   final String nodeName,
+                                                   final State nodeRole)
+            throws Exception
+    {
+        final TestStateChangeListener roleListener = new TestStateChangeListener();
+        final ReplicatedEnvironmentFacade node = createReplicatedEnvironmentFacade(nodeName,
+                                                                                   roleListener,
+                                                                                   new NoopReplicationGroupListener(),
+                                                                                   node1Config);
+        assertTrue("Environment was not created",
+                   roleListener.awaitForStateChange(nodeRole, _timeout, TimeUnit.SECONDS));
+        return node;
+    }
+
+    private DatabaseConfig createDatabaseConfig()
+    {
+        final DatabaseConfig createConfig = new DatabaseConfig();
+        createConfig.setAllowCreate(true);
+        createConfig.setTransactional(true);
+        return createConfig;
+    }
+
+    private String getTestKeyValue(final Database db, final int keyValue)
+    {
+        final DatabaseEntry key = new DatabaseEntry();
+        final DatabaseEntry result = new DatabaseEntry();
+        IntegerBinding.intToEntry(keyValue, key);
+        final OperationStatus status = db.get(null, key, result, LockMode.DEFAULT);
+        if (status == OperationStatus.SUCCESS)
+        {
+            return StringBinding.entryToString(result);
+        }
+        return null;
+    }
+
+    private void putRecord(final ReplicatedEnvironmentFacade master,
+                           final Database db,
+                           final int key,
+                           final String value,
+                           final boolean commitNosync)
+    {
+        final DatabaseEntry keyEntry = new DatabaseEntry();
+        IntegerBinding.intToEntry(key, keyEntry);
+        final DatabaseEntry dataEntry = new DatabaseEntry();
+        StringBinding.stringToEntry(value, dataEntry);
+
+        final TransactionConfig transactionConfig = new TransactionConfig();
+        transactionConfig.setDurability(master.getRealMessageStoreDurability());
+        final Transaction txn = master.beginTransaction(transactionConfig);
+        db.put(txn, keyEntry, dataEntry);
+        if (commitNosync)
+        {
+            master.commitNoSync(txn);
+        }
+        else
+        {
+            master.commit(txn);
+        }
+    }
 
     private void createIntruder(String nodeName, String node1NodeHostPort)
     {
