@@ -391,7 +391,7 @@ public class GroupBrokerAdmin
         return members;
     }
 
-    GroupMember getMemberByAmqpPort(final int amqpPort)
+    private GroupMember getMemberByAmqpPort(final int amqpPort)
     {
         return Arrays.stream(_members)
                      .filter(m -> m.getAmqpPort() == amqpPort)
@@ -521,15 +521,5 @@ public class GroupBrokerAdmin
         {
             return _nodeAttributes;
         }
-
-        @Override
-        public String toString()
-        {
-            return "GroupMember{" +
-                   "name='" + _name + '\'' +
-                   ",bdbPort=" + _bdbPort +
-                   ",amqpPort=" + _amqpPort +
-                   '}';
-        }
     }
 }
