@@ -101,6 +101,11 @@ public abstract class AbstractContainer<X extends AbstractContainer<X>> extends
         {
             _confidentialConfigurationEncryptionProvider =
                     String.valueOf(attributes.get(CONFIDENTIAL_CONFIGURATION_ENCRYPTION_PROVIDER));
+
+            // resolve context attributes here
+            // as encrypter factory relies on context variables
+            onResolve();
+            updateEncrypter(_confidentialConfigurationEncryptionProvider);
         }
 
     }
@@ -109,10 +114,6 @@ public abstract class AbstractContainer<X extends AbstractContainer<X>> extends
     protected void postResolveChildren()
     {
         super.postResolveChildren();
-        if (_confidentialConfigurationEncryptionProvider != null)
-        {
-            updateEncrypter(_confidentialConfigurationEncryptionProvider);
-        }
     }
 
     @SuppressWarnings("unused")
