@@ -88,6 +88,7 @@ public interface Queue<X extends Queue<X>> extends ConfiguredObject<X>,
     String MAXIMUM_QUEUE_DEPTH_MESSAGES = "maximumQueueDepthMessages";
     String MAXIMUM_QUEUE_DEPTH_BYTES = "maximumQueueDepthBytes";
     String EXPIRY_POLICY = "expiryPolicy";
+    String MAXIMUM_LIVE_CONSUMERS = "maximumLiveConsumers";
 
     String QUEUE_SCAVANGE_COUNT = "qpid.queue.scavenge_count";
     @SuppressWarnings("unused")
@@ -105,17 +106,24 @@ public interface Queue<X extends Queue<X>> extends ConfiguredObject<X>,
                                                  + "\"image/tiff\":\".tiff\","
                                                  + "\"text/plain\":\".txt\"}";
 
+    String QUEUE_DEFAULT_ALTERNATE_BINDING = "queue.defaultAlternateBinding";
+    @SuppressWarnings("unused")
+    @ManagedContextDefault( name = QUEUE_DEFAULT_ALTERNATE_BINDING,
+            description = "the ExclusivityPolicy to apply to queues where none is explicitly set")
+    String DEFAULT_ALTERNATE_BINDING = "";
+
+    @ManagedAttribute(defaultValue = "${queue.defaultAlternateBinding}", initialization = Initialization.materialize,
+                      description = "Provides an alternate destination that will be used when the number of delivery "
+                                    + "attempts exceeds the maximumDeliveryAttempt configured on this queue.  Messages "
+                                    + "are also routed to this destination if this queue is deleted.")
+    AlternateBinding getAlternateBinding();
+
     String QUEUE_DEFAULT_EXCLUSIVITY_POLICY = "queue.defaultExclusivityPolicy";
     @SuppressWarnings("unused")
     @ManagedContextDefault( name = QUEUE_DEFAULT_EXCLUSIVITY_POLICY,
             description = "the ExclusivityPolicy to apply to queues where none is explicitly set")
     String DEFAULT_EXCLUSIVITY = "NONE";
 
-    @ManagedAttribute(description = "Provides an alternate destination that will be used when the number of delivery "
-                                    + "attempts exceeds the maximumDeliveryAttempt configured on this queue.  Messages "
-                                    + "are also routed to this destination if this queue is deleted.")
-    AlternateBinding getAlternateBinding();
-
     @ManagedAttribute( defaultValue = "${queue.defaultExclusivityPolicy}")
     ExclusivityPolicy getExclusive();
 
@@ -349,6 +357,18 @@ public interface Queue<X extends Queue<X>> extends ConfiguredObject<X>,
             mandatory = true)
     ExpiryPolicy getExpiryPolicy();
 
+    @SuppressWarnings("unused")
+    @ManagedContextDefault(name = "queue.defaultMaximumLiveConsumers",
+            description = "Specifies the default value for maximum live consumers. ")
+    int DEFAULT_MAXIMUM_LIVE_CONSUMERS = 0;
+
+    @ManagedAttribute(defaultValue = "${queue.defaultMaximumLiveConsumers}",
+            description = "Maximum live consumers. If the maximum number of live consumers is set to a number greater "
+                          + "than zero, then consumers in excess of this limit are held in reserve and will only become "
+                          + "eligible to receive messages if a live consumer is removed")
+    int getMaximumLiveConsumers();
+
+
     @ManagedOperation(nonModifying = true, changesConfiguredObjectState = false, skipAclCheck = true)
     Collection<PublishingLink> getPublishingLinks();
 
