@@ -45,6 +45,8 @@ import org.apache.qpid.server.filter.JMSSelectorFilter;
 import org.apache.qpid.server.filter.MessageFilter;
 import org.apache.qpid.server.filter.SelectorParsingException;
 import org.apache.qpid.server.logging.EventLogger;
+import org.apache.qpid.server.logging.LogMessage;
+import org.apache.qpid.server.logging.Outcome;
 import org.apache.qpid.server.logging.LogSubject;
 import org.apache.qpid.server.logging.messages.SubscriptionMessages;
 import org.apache.qpid.server.logging.subjects.QueueLogSubject;
@@ -102,6 +104,7 @@ class QueueConsumerImpl<T extends ConsumerTarget>
     private final String _linkName;
 
     private volatile QueueConsumerNode _queueConsumerNode;
+    private volatile boolean _nonLive;
 
     QueueConsumerImpl(final AbstractQueue<?> queue,
                       T target,
@@ -193,7 +196,7 @@ class QueueConsumerImpl<T extends ConsumerTarget>
     @Override
     public boolean isNotifyWorkDesired()
     {
-        return _target.isNotifyWorkDesired();
+        return !isNonLive() && _target.isNotifyWorkDesired();
     }
 
     @Override
@@ -544,6 +547,16 @@ class QueueConsumerImpl<T extends ConsumerTarget>
         return _selector;
     }
 
+    @Override
+    public boolean isNonLive()
+    {
+        return _nonLive;
+    }
+
+    public void setNonLive(final boolean nonLive)
+    {
+        _nonLive = nonLive;
+    }
 
     @Override
     public String toLogString()
@@ -557,7 +570,7 @@ class QueueConsumerImpl<T extends ConsumerTarget>
         }
         else
         {
-            String queueString = new QueueLogSubject(_queue).toLogString();
+            String queueString = new QueueLogSubject(getName(), getName()).toLogString();
             logString = "[" + MessageFormat.format(SUBSCRIPTION_FORMAT, getConsumerNumber())
                                      + "("
                                      // queueString is [vh(/{0})/qu({1}) ] so need to trim
@@ -616,4 +629,25 @@ class QueueConsumerImpl<T extends ConsumerTarget>
         }
 
     }
+
+    @Override
+    protected void logCreated(final Map<String, Object> attributes,
+                              final Outcome outcome)
+    {
+        LOGGER.debug("{} : {} ({}) : Create : {}",
+                     LogMessage.getActor(),
+                     getCategoryClass().getSimpleName(),
+                     getName(),
+                     outcome);
+    }
+
+    @Override
+    protected void logDeleted(final Outcome outcome)
+    {
+        LOGGER.debug("{} : {} ({}) : Delete : {}",
+                     LogMessage.getActor(),
+                     getCategoryClass().getSimpleName(),
+                     getName(),
+                     outcome);
+    }
 }
