@@ -68,6 +68,7 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         register(new Upgrader_6_0_to_6_1());
         register(new Upgrader_6_1_to_7_0());
         register(new Upgrader_7_0_to_7_1());
+        register(new Upgrader_7_1_to_8_0());
     }
 
     private static final class Upgrader_1_0_to_1_1 extends StoreUpgraderPhase
@@ -708,6 +709,30 @@ public class BrokerStoreUpgraderAndRecoverer extends AbstractConfigurationStoreU
         }
     }
 
+    private class Upgrader_7_1_to_8_0 extends StoreUpgraderPhase
+    {
+
+        public Upgrader_7_1_to_8_0()
+        {
+            super("modelVersion", "7.1", "8.0");
+        }
+
+        @Override
+        public void configuredObject(final ConfiguredObjectRecord record)
+        {
+            if("Broker".equals(record.getType()))
+            {
+                upgradeRootRecord(record);
+            }
+        }
+
+        @Override
+        public void complete()
+        {
+
+        }
+    }
+
     private static class VirtualHostEntryUpgrader
     {
         @SuppressWarnings("serial")
