@@ -53,6 +53,7 @@ import org.apache.qpid.server.configuration.updater.TaskExecutor;
 import org.apache.qpid.server.connection.ConnectionPrincipal;
 import org.apache.qpid.server.logging.EventLogger;
 import org.apache.qpid.server.logging.EventLoggerProvider;
+import org.apache.qpid.server.logging.Outcome;
 import org.apache.qpid.server.logging.LogSubject;
 import org.apache.qpid.server.logging.messages.ConnectionMessages;
 import org.apache.qpid.server.logging.subjects.ConnectionLogSubject;
@@ -83,6 +84,7 @@ import org.apache.qpid.server.util.Action;
 import org.apache.qpid.server.util.ConnectionScopedRuntimeException;
 import org.apache.qpid.server.util.FixedKeyMapCreator;
 import org.apache.qpid.server.util.ServerScopedRuntimeException;
+import org.apache.qpid.server.virtualhost.ConnectionPrincipalStatistics;
 import org.apache.qpid.server.virtualhost.QueueManagingVirtualHost;
 
 public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,T>, T>
@@ -142,12 +144,13 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
 
     private volatile boolean _messageAuthorizationRequired;
 
-    private final AtomicLong _maxMessageSize = new AtomicLong(Long.MAX_VALUE);
+    private final AtomicLong _maxMessageSize = new AtomicLong(Integer.MAX_VALUE);
     private volatile int _messageCompressionThreshold;
     private volatile TransactionObserver _transactionObserver;
     private long _maxUncommittedInMemorySize;
 
     private final Map<ServerTransaction, Set<Ticker>> _transactionTickers = new ConcurrentHashMap<>();
+    private volatile ConnectionPrincipalStatistics _connectionPrincipalStatistics;
 
     public AbstractAMQPConnection(Broker<?> broker,
                                   ServerNetworkConnection network,
@@ -216,7 +219,6 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
         _lastReadTime = _lastWriteTime = _lastMessageInboundTime = _lastMessageOutboundTime = getCreatedTime().getTime();
         _maxUncommittedInMemorySize = getContextValue(Long.class, Connection.MAX_UNCOMMITTED_IN_MEMORY_SIZE);
         _transactionObserver = _maxUncommittedInMemorySize < 0 ? FlowToDiskTransactionObserver.NOOP_TRANSACTION_OBSERVER : new FlowToDiskTransactionObserver(_maxUncommittedInMemorySize, _logSubject, _eventLoggerProvider.getEventLogger());
-        logConnectionOpen();
     }
 
     @Override
@@ -398,19 +400,18 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
 
     private long getMaxMessageSize(final ContextProvider object)
     {
-        long maxMessageSize;
         try
         {
-            maxMessageSize = object.getContextValue(Integer.class, MAX_MESSAGE_SIZE);
+            final int maxMessageSize = object.getContextValue(Integer.class, MAX_MESSAGE_SIZE);
+            return maxMessageSize > 0 ? maxMessageSize : Integer.MAX_VALUE;
         }
         catch (NullPointerException | IllegalArgumentException e)
         {
             LOGGER.warn("Context variable {} has invalid value and cannot be used to restrict maximum message size",
-                         MAX_MESSAGE_SIZE,
-                         e);
-            maxMessageSize = Long.MAX_VALUE;
+                    MAX_MESSAGE_SIZE,
+                    e);
         }
-        return maxMessageSize > 0 ? maxMessageSize : Long.MAX_VALUE;
+        return Integer.MAX_VALUE;
     }
 
     @Override
@@ -664,7 +665,6 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
     @Override
     protected ListenableFuture<Void> onDelete()
     {
-        getEventLogger().message(_logSubject, ConnectionMessages.MODEL_DELETE());
         return closeAsyncIfNotAlreadyClosing();
     }
 
@@ -1157,4 +1157,43 @@ public abstract class AbstractAMQPConnection<C extends AbstractAMQPConnection<C,
     {
         _localTransactionBegins.incrementAndGet();
     }
+
+    @Override
+    public void registered(final ConnectionPrincipalStatistics connectionPrincipalStatistics)
+    {
+        _connectionPrincipalStatistics = connectionPrincipalStatistics;
+    }
+
+    @Override
+    public int getAuthenticatedPrincipalConnectionCount()
+    {
+        if (_connectionPrincipalStatistics == null)
+        {
+            return 0;
+        }
+        return _connectionPrincipalStatistics.getConnectionCount();
+    }
+
+    @Override
+    public int getAuthenticatedPrincipalConnectionFrequency()
+    {
+        if (_connectionPrincipalStatistics == null)
+        {
+            return 0;
+        }
+        return _connectionPrincipalStatistics.getConnectionFrequency();
+    }
+
+    @Override
+    protected void logCreated(final Map<String, Object> attributes,
+                              final Outcome outcome)
+    {
+        logConnectionOpen();
+    }
+
+    @Override
+    protected void logDeleted(final Outcome outcome)
+    {
+        getEventLogger().message(_logSubject, ConnectionMessages.MODEL_DELETE());
+    }
 }
