@@ -56,8 +56,10 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Date;
 import java.util.Enumeration;
+import java.util.HashMap;
 import java.util.Iterator;
 import java.util.List;
+import java.util.Map;
 import java.util.Set;
 import java.util.SortedSet;
 import java.util.TreeSet;
@@ -75,8 +77,8 @@ import javax.net.ssl.StandardConstants;
 import javax.net.ssl.TrustManager;
 import javax.net.ssl.X509TrustManager;
 
-
 import org.apache.qpid.server.util.ConnectionScopedRuntimeException;
+import org.apache.qpid.server.util.ServerScopedRuntimeException;
 import org.slf4j.Logger;
 import org.slf4j.LoggerFactory;
 
@@ -108,11 +110,10 @@ public class SSLUtil
     private static final Method SET_EXTENSION_METHOD;
     private static final Method EXTENSION_GET_NAME_METHOD;
     private static final boolean CAN_GENERATE_CERTS;
-
+    private static final CertificateFactory CERTIFICATE_FACTORY;
 
     static
     {
-
         Constructor<?> constructor = null;
         Method generateMethod = null;
         Method getPrivateKeyMethod = null;
@@ -127,7 +128,17 @@ public class SSLUtil
         Constructor<?> certificateExtensionsConstructor = null;
         Method setExtensionMethod = null;
         Method extensionGetNameMethod = null;
-        boolean canGenerateCerrts = false;
+        boolean canGenerateCerts = false;
+        CertificateFactory certificateFactory = null;
+
+        try
+        {
+            certificateFactory = CertificateFactory.getInstance("X.509");
+        }
+        catch (CertificateException e)
+        {
+            // ignore
+        }
 
         try
         {
@@ -162,8 +173,7 @@ public class SSLUtil
             certificateExtensionsConstructor = certificateExtensionsClass.getConstructor();
             setExtensionMethod = certificateExtensionsClass.getMethod("set", String.class, Object.class);
             extensionGetNameMethod = extensionClass.getMethod("getName");
-            canGenerateCerrts = true;
-
+            canGenerateCerts = true;
         }
         catch (ClassNotFoundException | LinkageError | NoSuchMethodException e)
         {
@@ -183,14 +193,23 @@ public class SSLUtil
         CERTIFICATE_EXTENSIONS_CONSTRUCTOR = certificateExtensionsConstructor;
         SET_EXTENSION_METHOD = setExtensionMethod;
         EXTENSION_GET_NAME_METHOD = extensionGetNameMethod;
-        CAN_GENERATE_CERTS = canGenerateCerrts;
+        CAN_GENERATE_CERTS = canGenerateCerts;
+        CERTIFICATE_FACTORY = certificateFactory;
     }
 
-
     private SSLUtil()
     {
     }
 
+    public static CertificateFactory getCertificateFactory()
+    {
+        if (CERTIFICATE_FACTORY == null)
+        {
+            throw new ServerScopedRuntimeException("Certificate factory is null");
+        }
+        return CERTIFICATE_FACTORY;
+    }
+
     public static void verifyHostname(SSLEngine engine,String hostnameExpected)
     {
         try
@@ -458,8 +477,7 @@ public class SSLUtil
         {
             do
             {
-                CertificateFactory cf = CertificateFactory.getInstance("X.509");
-                crt.add( (X509Certificate) cf.generateCertificate(input));
+                crt.add( (X509Certificate) getCertificateFactory().generateCertificate(input));
             } while(input.available() != 0);
         }
         catch(CertificateException e)
@@ -1035,16 +1053,30 @@ public class SSLUtil
 
     }
 
+    /**
+     * Get keystore certificates
+     * @deprecated
+     * The signature of this method is changed in version 9.0 and onwards.
+     * <p> Use {@link SSLUtil#getCertificatesAsMap(KeyStore)} instead.
+     *
+     * @return cllection of keystore certificates
+     */
+    @Deprecated
     public static Collection<Certificate> getCertificates(final KeyStore ks) throws KeyStoreException
     {
-        List<Certificate> certificates = new ArrayList<>();
-        Enumeration<String> aliases = ks.aliases();
+        return getCertificatesAsMap(ks).values();
+    }
+
+    public static Map<String, Certificate> getCertificatesAsMap(final KeyStore ks) throws KeyStoreException
+    {
+        final Map<String ,Certificate> certificates = new HashMap<>();
+        final Enumeration<String> aliases = ks.aliases();
         while (aliases.hasMoreElements())
         {
-            String alias = aliases.nextElement();
+            final String alias = aliases.nextElement();
             if (ks.isCertificateEntry(alias))
             {
-                certificates.add(ks.getCertificate(alias));
+                certificates.put(alias, ks.getCertificate(alias));
             }
         }
         return certificates;
