@@ -104,6 +104,11 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
                                          + " link detaches. This is to avoid leaking links with the Qpid JMS client.")
     boolean DEFAULT_DISCARD_GLOBAL_SHARED_SUBSCRIPTION_LINKS_ON_DETACH = true;
 
+    String CONNECTION_FREQUENCY_PERIOD = "qpid.virtualhost.connectionFrequencyPeriodInMillis";
+    @ManagedContextDefault(name = CONNECTION_FREQUENCY_PERIOD, description = "Interval (in milliseconds) to evaluate connection frequency")
+    @SuppressWarnings("unused")
+    long DEFAULT_CONNECTION_FREQUENCY_PERIOD = 60 * 1000;
+
     @ManagedAttribute( defaultValue = "${" + VIRTUALHOST_STATISTICS_REPORING_PERIOD + "}", description = "Period (in seconds) of the statistic report.")
     int getStatisticsReportingPeriod();
 
@@ -275,6 +280,13 @@ public interface QueueManagingVirtualHost<X extends QueueManagingVirtualHost<X>>
                       description="Current size of all messages cached in-memory.", metricName = "in_memory_message_size_bytes_total")
     long getInMemoryMessageSize();
 
+    @SuppressWarnings("unused")
+    @ManagedStatistic(statisticType = StatisticType.POINT_IN_TIME, units = StatisticUnit.BYTES,
+            label = "In-Memory Message Bytes Threshold",
+            description="A threshold for triggering flow to disk when the size of all messages cached in-memory exceeds the value.",
+            metricName = "in_memory_message_threshold_bytes_total")
+    long getInMemoryMessageThreshold();
+
     @SuppressWarnings("unused")
     @ManagedStatistic(statisticType = StatisticType.CUMULATIVE, units = StatisticUnit.BYTES, label = "Evacuated Message Bytes",
                       description = "Total Number of Bytes Evacuated from Memory Due to Flow to Disk.")
