@@ -30,7 +30,6 @@ import java.util.Arrays;
 import java.util.Collection;
 import java.util.Collections;
 import java.util.EnumSet;
-import java.util.HashMap;
 import java.util.HashSet;
 import java.util.List;
 import java.util.Map;
@@ -53,12 +52,14 @@ import com.google.common.base.Joiner;
 import com.google.common.util.concurrent.Futures;
 import com.google.common.util.concurrent.ListenableFuture;
 import com.google.common.util.concurrent.SettableFuture;
+import org.eclipse.jetty.http.HttpVersion;
 import org.eclipse.jetty.io.Connection;
 import org.eclipse.jetty.io.ssl.SslHandshakeListener;
 import org.eclipse.jetty.server.ConnectionFactory;
 import org.eclipse.jetty.server.HttpConfiguration;
 import org.eclipse.jetty.server.HttpConnectionFactory;
 import org.eclipse.jetty.server.NetworkConnector;
+import org.eclipse.jetty.server.OptionalSslConnectionFactory;
 import org.eclipse.jetty.server.SecureRequestCustomizer;
 import org.eclipse.jetty.server.Server;
 import org.eclipse.jetty.server.ServerConnector;
@@ -82,12 +83,11 @@ import org.apache.qpid.server.logging.messages.ManagementConsoleMessages;
 import org.apache.qpid.server.logging.messages.PortMessages;
 import org.apache.qpid.server.management.plugin.filter.AuthenticationCheckFilter;
 import org.apache.qpid.server.management.plugin.filter.ExceptionHandlingFilter;
-import org.apache.qpid.server.management.plugin.filter.ForbiddingTraceFilter;
 import org.apache.qpid.server.management.plugin.filter.InteractiveAuthenticationFilter;
 import org.apache.qpid.server.management.plugin.filter.LoggingFilter;
+import org.apache.qpid.server.management.plugin.filter.MethodFilter;
 import org.apache.qpid.server.management.plugin.filter.RedirectFilter;
 import org.apache.qpid.server.management.plugin.filter.RewriteRequestForUncompressedJavascript;
-import org.apache.qpid.server.management.plugin.portunification.TlsOrPlainConnectionFactory;
 import org.apache.qpid.server.management.plugin.servlet.FileServlet;
 import org.apache.qpid.server.management.plugin.servlet.RootServlet;
 import org.apache.qpid.server.management.plugin.servlet.ContentServlet;
@@ -348,8 +348,23 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
         corsFilter.setInitParameter(CrossOriginFilter.ALLOW_CREDENTIALS_PARAM, String.valueOf(getCorsAllowCredentials()));
         root.addFilter(corsFilter, "/*", EnumSet.of(DispatcherType.REQUEST));
 
-        root.addFilter(new FilterHolder(new ForbiddingTraceFilter()), "/*", EnumSet.of(DispatcherType.REQUEST));
+        root.addFilter(new FilterHolder(new MethodFilter()), "/*", EnumSet.of(DispatcherType.REQUEST));
 
+        addFiltersAndServletsForRest(root);
+        if (!Boolean.TRUE.equals(getContextValue(Boolean.class, DISABLE_UI_CONTEXT_NAME)))
+        {
+            addFiltersAndServletsForUserInterfaces(root);
+        }
+
+        root.getSessionHandler().getSessionCookieConfig().setName(JSESSIONID_COOKIE_PREFIX + lastPort);
+        root.getSessionHandler().getSessionCookieConfig().setHttpOnly(true);
+        root.getSessionHandler().setMaxInactiveInterval(getSessionTimeout());
+
+        return server;
+    }
+
+    private void addFiltersAndServletsForRest(final ServletContextHandler root)
+    {
         FilterHolder loggingFilter = new FilterHolder(new LoggingFilter());
         root.addFilter(loggingFilter, "/api/*", EnumSet.of(DispatcherType.REQUEST));
         root.addFilter(loggingFilter, "/service/*", EnumSet.of(DispatcherType.REQUEST));
@@ -357,22 +372,8 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
         FilterHolder restAuthorizationFilter = new FilterHolder(new AuthenticationCheckFilter());
         restAuthorizationFilter.setInitParameter(AuthenticationCheckFilter.INIT_PARAM_ALLOWED, "/service/sasl");
         root.addFilter(restAuthorizationFilter, "/api/*", EnumSet.of(DispatcherType.REQUEST));
-        root.addFilter(restAuthorizationFilter, "/apidocs/*", EnumSet.of(DispatcherType.REQUEST));
         root.addFilter(restAuthorizationFilter, "/service/*", EnumSet.of(DispatcherType.REQUEST));
 
-        root.addFilter(new FilterHolder(new InteractiveAuthenticationFilter()), "/index.html", EnumSet.of(DispatcherType.REQUEST));
-        root.addFilter(new FilterHolder(new InteractiveAuthenticationFilter()), "/", EnumSet.of(DispatcherType.REQUEST));
-
-        FilterHolder redirectFilter = new FilterHolder(new RedirectFilter());
-        redirectFilter.setInitParameter(RedirectFilter.INIT_PARAM_REDIRECT_URI, "/index.html");
-        root.addFilter(redirectFilter, "/login.html", EnumSet.of(DispatcherType.REQUEST));
-
-        if (_serveUncompressedDojo)
-        {
-            root.addFilter(RewriteRequestForUncompressedJavascript.class, "/dojo/dojo/*", EnumSet.of(DispatcherType.REQUEST));
-            root.addFilter(RewriteRequestForUncompressedJavascript.class, "/dojo/dojox/*", EnumSet.of(DispatcherType.REQUEST));
-        }
-
         addRestServlet(root);
 
         ServletHolder queryServlet = new ServletHolder(new BrokerQueryServlet());
@@ -383,36 +384,9 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
         root.addServlet(vhQueryServlet, "/api/latest/queryvhost/*");
         root.addServlet(vhQueryServlet, "/api/v" + BrokerModel.MODEL_VERSION + "/queryvhost/*");
 
-
-        ServletHolder apiDocsServlet = new ServletHolder(new ApiDocsServlet());
-        final String version = "v" + BrokerModel.MODEL_VERSION;
-        for (final String path : new String[]{"/apidocs", "/apidocs/latest", "/apidocs/" + version})
-        {
-            root.addServlet(apiDocsServlet, path);
-            root.addServlet(apiDocsServlet, path + "/");
-        }
-
         root.addServlet(new ServletHolder(new StructureServlet()), "/service/structure");
         root.addServlet(new ServletHolder(new QueueReportServlet()), "/service/queuereport/*");
-
         root.addServlet(new ServletHolder(new MetaDataServlet()), "/service/metadata");
-
-        root.addServlet(new ServletHolder(new SaslServlet()), "/service/sasl");
-
-        root.addServlet(new ServletHolder(new RootServlet("/","/apidocs/","index.html")), "/");
-        root.addServlet(new ServletHolder(new LogoutServlet()), "/logout");
-
-        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDojoPath(), true)), "/dojo/dojo/*");
-        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDijitPath(), true)), "/dojo/dijit/*");
-        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDojoxPath(), true)), "/dojo/dojox/*");
-        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDgridPath(), true)), "/dojo/dgrid/*");
-        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDstorePath(), true)), "/dojo/dstore/*");
-
-        for(String pattern : STATIC_FILE_TYPES)
-        {
-            root.addServlet(new ServletHolder(new FileServlet()), pattern);
-        }
-
         root.addServlet(new ServletHolder(new TimeZoneServlet()), "/service/timezones");
 
         final Iterable<ContentFactory> contentFactories = new QpidServiceLoader().instancesOf(ContentFactory.class);
@@ -430,11 +404,62 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
 
         });
 
-        root.getSessionHandler().getSessionCookieConfig().setName(JSESSIONID_COOKIE_PREFIX + lastPort);
-        root.getSessionHandler().getSessionCookieConfig().setHttpOnly(true);
-        root.getSessionHandler().setMaxInactiveInterval(getSessionTimeout());
+    }
 
-        return server;
+    private void addFiltersAndServletsForUserInterfaces(final ServletContextHandler root)
+    {
+        root.addFilter(new FilterHolder(new AuthenticationCheckFilter()), "/apidocs/*", EnumSet.of(DispatcherType.REQUEST));
+        root.addFilter(new FilterHolder(new InteractiveAuthenticationFilter()), DEFAULT_LOGIN_URL, EnumSet.of(DispatcherType.REQUEST));
+        root.addFilter(new FilterHolder(new InteractiveAuthenticationFilter()), "/", EnumSet.of(DispatcherType.REQUEST));
+
+        FilterHolder redirectFilter = new FilterHolder(new RedirectFilter());
+        redirectFilter.setInitParameter(RedirectFilter.INIT_PARAM_REDIRECT_URI, DEFAULT_LOGIN_URL);
+        root.addFilter(redirectFilter, "/login.html", EnumSet.of(DispatcherType.REQUEST));
+
+        if (_serveUncompressedDojo)
+        {
+            root.addFilter(RewriteRequestForUncompressedJavascript.class, "/dojo/dojo/*", EnumSet.of(DispatcherType.REQUEST));
+            root.addFilter(RewriteRequestForUncompressedJavascript.class, "/dojo/dojox/*", EnumSet.of(DispatcherType.REQUEST));
+        }
+
+        addApiDocsServlets(root);
+
+        root.addServlet(new ServletHolder(new SaslServlet()), "/service/sasl");
+        root.addServlet(new ServletHolder(new RootServlet("/", "/apidocs/", "index.html")), "/");
+        root.addServlet(new ServletHolder(new LogoutServlet()), "/logout");
+        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDojoPath(), true)), "/dojo/dojo/*");
+        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDijitPath(), true)), "/dojo/dijit/*");
+        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDojoxPath(), true)), "/dojo/dojox/*");
+        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDgridPath(), true)), "/dojo/dgrid/*");
+        root.addServlet(new ServletHolder(new FileServlet(DojoHelper.getDstorePath(), true)), "/dojo/dstore/*");
+
+        for (String pattern : STATIC_FILE_TYPES)
+        {
+            root.addServlet(new ServletHolder(new FileServlet()), pattern);
+        }
+    }
+
+    private void addApiDocsServlets(final ServletContextHandler root)
+    {
+        final ApiDocsServlet apiDocsServlet = new ApiDocsServlet();
+        final ServletHolder apiDocsServletHolder = new ServletHolder(apiDocsServlet);
+        final String version = "v" + BrokerModel.MODEL_VERSION;
+        for (final String path : new String[]{"/apidocs", "/apidocs/latest", "/apidocs/" + version})
+        {
+            root.addServlet(apiDocsServletHolder, path);
+            root.addServlet(apiDocsServletHolder, path + "/");
+        }
+
+        getModel().getSupportedCategories()
+                  .stream()
+                  .map(Class::getSimpleName)
+                  .map(String::toLowerCase)
+                  .forEach(name -> {
+                      root.addServlet(apiDocsServletHolder, "/apidocs/latest/" + name + "/");
+                      root.addServlet(apiDocsServletHolder, "/apidocs/" + version + "/" + name + "/");
+                      root.addServlet(apiDocsServletHolder, "/apidocs/latest/" + name);
+                      root.addServlet(apiDocsServletHolder, "/apidocs/" + version + "/" + name);
+                  });
     }
 
     @Override
@@ -549,15 +574,11 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
         else if (transports.contains(Transport.SSL))
         {
             sslContextFactory = createSslContextFactory(port);
-            ConnectionFactory sslConnectionFactory;
+            ConnectionFactory sslConnectionFactory =
+                    new SslConnectionFactory(sslContextFactory, httpConnectionFactory.getProtocol());
             if (port.getTransports().contains(Transport.TCP))
             {
-                sslConnectionFactory =
-                        new TlsOrPlainConnectionFactory(sslContextFactory, httpConnectionFactory.getProtocol());
-            }
-            else
-            {
-                sslConnectionFactory = new SslConnectionFactory(sslContextFactory, httpConnectionFactory.getProtocol());
+                sslConnectionFactory = new OptionalSslConnectionFactory((SslConnectionFactory)sslConnectionFactory, HttpVersion.HTTP_1_1.asString());
             }
             connectionFactories = new ConnectionFactory[]{sslConnectionFactory, httpConnectionFactory};
         }
@@ -729,8 +750,10 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
     private void addRestServlet(final ServletContextHandler root)
     {
         final Map<String, ManagementControllerFactory> factories = ManagementControllerFactory.loadFactories();
-        final ApiDocsServlet apiDocsServlet = new ApiDocsServlet();
+        final long maxFileSize = getContextValue(Long.class, MAX_HTTP_FILE_UPLOAD_SIZE_CONTEXT_NAME);
+        final int maxRequestSize = getContextValue(Integer.class, MAX_HTTP_FILE_UPLOAD_SIZE_CONTEXT_NAME);
         final List<String> supportedVersions = new ArrayList<>();
+        supportedVersions.add("latest");
         String currentVersion = BrokerModel.MODEL_VERSION;
         ManagementController managementController = null;
         ManagementControllerFactory factory;
@@ -750,23 +773,13 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
                     servletHolder.setInitParameter("qpid.controller.version", managementController.getVersion());
 
                     servletHolder.getRegistration().setMultipartConfig(
-                            new MultipartConfigElement("",
-                                                       getContextValue(Long.class,
-                                                                       MAX_HTTP_FILE_UPLOAD_SIZE_CONTEXT_NAME),
-                                                       -1L,
-                                                       getContextValue(Integer.class,
-                                                                       MAX_HTTP_FILE_UPLOAD_SIZE_CONTEXT_NAME)));
+                            new MultipartConfigElement("", maxFileSize, -1L, maxRequestSize));
 
                     root.addServlet(servletHolder, path + (path.endsWith("/") ? "*" : "/*"));
 
                     if (BrokerModel.MODEL_VERSION.equals(managementController.getVersion()))
                     {
                         root.addServlet(servletHolder, "/api/latest/" + name + "/*");
-                        ServletHolder docServletHolder = new ServletHolder(name + "docs", apiDocsServlet);
-                        root.addServlet(docServletHolder, "/apidocs/latest/" + name + "/");
-                        root.addServlet(docServletHolder, "/apidocs/v" + BrokerModel.MODEL_VERSION + "/" + name + "/");
-                        root.addServlet(docServletHolder, "/apidocs/latest/" + name);
-                        root.addServlet(docServletHolder, "/apidocs/v" + BrokerModel.MODEL_VERSION + "/" + name);
                     }
                 }
                 supportedVersions.add("v" + currentVersion);
@@ -871,7 +884,7 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
     @SuppressWarnings("unused")
     public static Set<String> getAllAvailableCorsMethodCombinations()
     {
-        List<String> methods = Arrays.asList("OPTION", "HEAD", "GET", "POST", "PUT", "DELETE");
+        List<String> methods = Arrays.asList("OPTIONS", "HEAD", "GET", "POST", "PUT", "DELETE");
         Set<Set<String>> combinations = new HashSet<>();
         int n = methods.size();
         assert n < 31 : "Too many combination to calculate";
@@ -947,7 +960,7 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
         public QBBTrackingThreadPool(@Name("maxThreads") final int maxThreads, @Name("minThreads") final int minThreads)
         {
             super(maxThreads, minThreads);
-            _threadFactory = QpidByteBuffer.createQpidByteBufferTrackingThreadFactory(r -> QBBTrackingThreadPool.super.newThread(r));
+            _threadFactory = QpidByteBuffer.createQpidByteBufferTrackingThreadFactory(QBBTrackingThreadPool.super::newThread);
         }
 
         @Override
@@ -1055,7 +1068,7 @@ public class HttpManagement extends AbstractPluginAdapter<HttpManagement> implem
 
     private static class ConnectionTrackingListener implements Connection.Listener
     {
-        private final Map<Connection, SettableFuture<Void>> _closeFutures = new HashMap<>();
+        private final Map<Connection, SettableFuture<Void>> _closeFutures = new ConcurrentHashMap<>();
 
         @Override
         public void onOpened(final Connection connection)
