@@ -26,7 +26,7 @@ import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.notNullValue;
 import static org.hamcrest.CoreMatchers.nullValue;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.junit.Assert.fail;
 import static org.mockito.Mockito.doReturn;
 import static org.mockito.Mockito.mock;
@@ -82,6 +82,7 @@ public class LatestManagementControllerTest extends UnitTestBase
     {
         final HttpManagementConfiguration<?> httpManagement = mock(HttpManagementConfiguration.class);
         when(httpManagement.getContextValue(Long.class, PREFERENCE_OPERTAION_TIMEOUT_CONTEXT_NAME)).thenReturn(1000L);
+        when(httpManagement.getModel()).thenReturn(BrokerModel.getInstance());
         _controller = new LatestManagementController(httpManagement);
     }
 
