@@ -328,7 +328,8 @@ class WebSocketProvider implements AcceptingTransport
 
     private static class QBBTrackingThreadPool extends QueuedThreadPool
     {
-        private final ThreadFactory _threadFactory = QpidByteBuffer.createQpidByteBufferTrackingThreadFactory(r -> QBBTrackingThreadPool.super.newThread(r));
+        private final ThreadFactory _threadFactory = QpidByteBuffer.createQpidByteBufferTrackingThreadFactory(
+                QBBTrackingThreadPool.super::newThread);
 
         @Override
         public Thread newThread(final Runnable runnable)
