@@ -20,16 +20,16 @@
 
 package org.apache.qpid.tests.protocol.v1_0.extensions.bindmapjms;
 
+import static org.hamcrest.CoreMatchers.instanceOf;
 import static org.hamcrest.CoreMatchers.notNullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.is;
+import static org.junit.Assume.assumeThat;
 
-import java.net.InetSocketAddress;
 import java.util.Collections;
 
 import org.hamcrest.Matchers;
-import org.junit.Before;
 import org.junit.Test;
 
 import org.apache.qpid.server.protocol.v1_0.Session_1_0;
@@ -44,26 +44,18 @@ import org.apache.qpid.server.protocol.v1_0.type.transport.Attach;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Begin;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Detach;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Flow;
-import org.apache.qpid.server.protocol.v1_0.type.transport.Open;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Role;
+import org.apache.qpid.tests.protocol.Response;
 import org.apache.qpid.tests.protocol.SpecificationTest;
 import org.apache.qpid.tests.protocol.v1_0.FrameTransport;
 import org.apache.qpid.tests.protocol.v1_0.Interaction;
 import org.apache.qpid.tests.protocol.v1_0.Utils;
-import org.apache.qpid.tests.utils.BrokerAdmin;
 import org.apache.qpid.tests.utils.BrokerAdminUsingTestBase;
 
 public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
 {
     private static final Symbol TEMPORARY_QUEUE = Symbol.valueOf("temporary-queue");
     private static final Symbol TEMPORARY_TOPIC = Symbol.valueOf("temporary-topic");
-    private InetSocketAddress _brokerAddress;
-
-    @Before
-    public void setUp()
-    {
-        _brokerAddress = getBrokerAdmin().getBrokerAddress(BrokerAdmin.PortType.ANONYMOUS_AMQP);
-    }
 
     @Test
     @SpecificationTest(section = "5.3",
@@ -89,17 +81,17 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
     {
         String newTemporaryNodeAddress;
 
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             Target target = createTarget(targetCapabilities);
 
             final Interaction interaction = transport.newInteraction();
-            final Attach attachResponse = interaction.negotiateProtocol().consumeResponse()
-                                                     .open().consumeResponse(Open.class)
+            final Attach attachResponse = interaction.negotiateOpen()
                                                      .begin().consumeResponse(Begin.class)
                                                      .attachRole(Role.SENDER)
                                                      .attachTarget(target)
                                                      .attach().consumeResponse()
+                                                     .assertLatestResponse(this::assumeAttachResponse)
                                                      .getLatestResponse(Attach.class);
 
             assertThat(attachResponse.getSource(), is(notNullValue()));
@@ -113,7 +105,7 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
             interaction.doCloseConnection();
         }
 
-        assertThat(Utils.doesNodeExist(_brokerAddress, newTemporaryNodeAddress), is(false));
+        assertThat(Utils.doesNodeExist(getBrokerAdmin(), newTemporaryNodeAddress), is(false));
     }
 
 
@@ -138,19 +130,19 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
     public void createTemporaryQueueReceivingLink() throws Exception
     {
         final Symbol[] capabilities = new Symbol[]{TEMPORARY_QUEUE};
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             Target target = createTarget(capabilities);
 
             final Interaction interaction = transport.newInteraction();
             final UnsignedInteger senderHandle = UnsignedInteger.ONE;
-            final Attach senderAttachResponse = interaction.negotiateProtocol().consumeResponse()
-                                                           .open().consumeResponse(Open.class)
+            final Attach senderAttachResponse = interaction.negotiateOpen()
                                                            .begin().consumeResponse(Begin.class)
                                                            .attachRole(Role.SENDER)
                                                            .attachHandle(senderHandle)
                                                            .attachTarget(target)
                                                            .attach().consumeResponse()
+                                                           .assertLatestResponse(this::assumeAttachResponse)
                                                            .getLatestResponse(Attach.class);
 
             assertThat(senderAttachResponse.getSource(), is(notNullValue()));
@@ -198,19 +190,19 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
     public void createTemporaryQueueReceivingLinkFromOtherConnectionDisallowed() throws Exception
     {
         final Symbol[] capabilities = new Symbol[]{TEMPORARY_QUEUE};
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             Target target = createTarget(capabilities);
 
             final Interaction interaction = transport.newInteraction();
             final UnsignedInteger senderHandle = UnsignedInteger.ONE;
-            final Attach senderAttachResponse = interaction.negotiateProtocol().consumeResponse()
-                                                           .open().consumeResponse(Open.class)
+            final Attach senderAttachResponse = interaction.negotiateOpen()
                                                            .begin().consumeResponse(Begin.class)
                                                            .attachRole(Role.SENDER)
                                                            .attachHandle(senderHandle)
                                                            .attachTarget(target)
                                                            .attach().consumeResponse()
+                                                           .assertLatestResponse(this::assumeAttachResponse)
                                                            .getLatestResponse(Attach.class);
 
             assertThat(senderAttachResponse.getSource(), is(notNullValue()));
@@ -237,19 +229,19 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
     public void createTemporaryQueueSendingLinkFromOtherConnectionAllowed() throws Exception
     {
         final Symbol[] capabilities = new Symbol[]{TEMPORARY_QUEUE};
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             Target target = createTarget(capabilities);
 
             final Interaction interaction = transport.newInteraction();
             final UnsignedInteger senderHandle = UnsignedInteger.ONE;
-            final Attach senderAttachResponse = interaction.negotiateProtocol().consumeResponse()
-                                                           .open().consumeResponse(Open.class)
+            final Attach senderAttachResponse = interaction.negotiateOpen()
                                                            .begin().consumeResponse(Begin.class)
                                                            .attachRole(Role.SENDER)
                                                            .attachHandle(senderHandle)
                                                            .attachTarget(target)
                                                            .attach().consumeResponse()
+                                                           .assertLatestResponse(this::assumeAttachResponse)
                                                            .getLatestResponse(Attach.class);
 
             assertThat(senderAttachResponse.getSource(), is(notNullValue()));
@@ -288,7 +280,7 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
     public void createTemporaryTopicSubscriptionReceivingLink() throws Exception
     {
         final Symbol[] capabilities = new Symbol[]{TEMPORARY_TOPIC};
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Source source = new Source();
             source.setDynamicNodeProperties(Collections.singletonMap(Session_1_0.LIFETIME_POLICY, new DeleteOnClose()));
@@ -298,13 +290,13 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
 
             final Interaction interaction = transport.newInteraction();
             final UnsignedInteger receiverHandle = UnsignedInteger.ONE;
-            final Attach receiverAttachResponse = interaction.negotiateProtocol().consumeResponse()
-                                                             .open().consumeResponse(Open.class)
+            final Attach receiverAttachResponse = interaction.negotiateOpen()
                                                              .begin().consumeResponse(Begin.class)
                                                              .attachRole(Role.RECEIVER)
                                                              .attachSource(source)
                                                              .attachHandle(receiverHandle)
                                                              .attach().consumeResponse()
+                                                             .assertLatestResponse(this::assumeAttachResponse)
                                                              .getLatestResponse(Attach.class);
 
             assertThat(receiverAttachResponse.getSource(), is(notNullValue()));
@@ -352,7 +344,7 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
     public void createTemporaryTopicSubscriptionReceivingLinkFromOtherConnectionDisallowed() throws Exception
     {
         final Symbol[] capabilities = new Symbol[]{TEMPORARY_TOPIC};
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Source source = new Source();
             source.setDynamicNodeProperties(Collections.singletonMap(Session_1_0.LIFETIME_POLICY, new DeleteOnClose()));
@@ -362,13 +354,13 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
 
             final Interaction interaction = transport.newInteraction();
             final UnsignedInteger receiverHandle = UnsignedInteger.ONE;
-            final Attach receiverAttachResponse = interaction.negotiateProtocol().consumeResponse()
-                                                             .open().consumeResponse(Open.class)
+            final Attach receiverAttachResponse = interaction.negotiateOpen()
                                                              .begin().consumeResponse(Begin.class)
                                                              .attachRole(Role.RECEIVER)
                                                              .attachSource(source)
                                                              .attachHandle(receiverHandle)
                                                              .attach().consumeResponse()
+                                                             .assertLatestResponse(this::assumeAttachResponse)
                                                              .getLatestResponse(Attach.class);
 
             assertThat(receiverAttachResponse.getSource(), is(notNullValue()));
@@ -393,7 +385,7 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
     public void createTemporaryTopicSendingLinkFromOtherConnectionAllowed() throws Exception
     {
         final Symbol[] capabilities = new Symbol[]{TEMPORARY_TOPIC};
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Source source = new Source();
             source.setDynamicNodeProperties(Collections.singletonMap(Session_1_0.LIFETIME_POLICY, new DeleteOnClose()));
@@ -403,13 +395,13 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
 
             final Interaction interaction = transport.newInteraction();
             final UnsignedInteger receiverHandle = UnsignedInteger.ONE;
-            final Attach receiverAttachResponse = interaction.negotiateProtocol().consumeResponse()
-                                                             .open().consumeResponse(Open.class)
+            final Attach receiverAttachResponse = interaction.negotiateOpen()
                                                              .begin().consumeResponse(Begin.class)
                                                              .attachRole(Role.RECEIVER)
                                                              .attachSource(source)
                                                              .attachHandle(receiverHandle)
                                                              .attach().consumeResponse()
+                                                             .assertLatestResponse(this::assumeAttachResponse)
                                                              .getLatestResponse(Attach.class);
 
             assertThat(receiverAttachResponse.getSource(), is(notNullValue()));
@@ -425,13 +417,10 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
 
     private void assertReceivingLinkFails(final Source source, final AmqpError expectedError) throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             final Interaction interaction = transport.newInteraction();
-            final Detach responseDetach = interaction.negotiateProtocol()
-                                                     .consumeResponse()
-                                                     .open()
-                                                     .consumeResponse(Open.class)
+            final Detach responseDetach = interaction.negotiateOpen()
                                                      .begin()
                                                      .consumeResponse(Begin.class)
                                                      .attachRole(Role.RECEIVER)
@@ -449,16 +438,13 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
 
     private void assertSendingLinkSucceeds(final String address) throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
             Target target = new Target();
             target.setAddress(address);
 
             final Interaction interaction = transport.newInteraction();
-            interaction.negotiateProtocol()
-                        .consumeResponse()
-                        .open()
-                        .consumeResponse(Open.class)
+            interaction.negotiateOpen()
                         .begin()
                         .consumeResponse(Begin.class)
                         .attachRole(Role.SENDER)
@@ -489,4 +475,10 @@ public class TemporaryDestinationTest extends BrokerAdminUsingTestBase
         source.setAddress(name);
         return source;
     }
+
+    private void assumeAttachResponse(Response<?> response)
+    {
+        assertThat(response, notNullValue());
+        assumeThat(response.getBody(), instanceOf(Attach.class));
+    }
 }
