@@ -22,17 +22,14 @@ package org.apache.qpid.tests.protocol.v1_0.messaging;
 
 import static java.nio.charset.StandardCharsets.UTF_8;
 import static org.hamcrest.CoreMatchers.instanceOf;
-import static org.hamcrest.CoreMatchers.nullValue;
 import static org.hamcrest.MatcherAssert.assertThat;
 import static org.hamcrest.Matchers.equalTo;
 import static org.hamcrest.Matchers.is;
 import static org.hamcrest.Matchers.oneOf;
 
-import java.net.InetSocketAddress;
 import java.util.HashMap;
 import java.util.Map;
 
-import org.junit.After;
 import org.junit.Before;
 import org.junit.Test;
 
@@ -42,48 +39,25 @@ import org.apache.qpid.server.protocol.v1_0.type.UnsignedInteger;
 import org.apache.qpid.server.protocol.v1_0.type.messaging.Accepted;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Attach;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Begin;
-import org.apache.qpid.server.protocol.v1_0.type.transport.Close;
-import org.apache.qpid.server.protocol.v1_0.type.transport.Detach;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Disposition;
-import org.apache.qpid.server.protocol.v1_0.type.transport.End;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Flow;
-import org.apache.qpid.server.protocol.v1_0.type.transport.Open;
-import org.apache.qpid.server.protocol.v1_0.type.transport.ReceiverSettleMode;
 import org.apache.qpid.server.protocol.v1_0.type.transport.Role;
+import org.apache.qpid.tests.protocol.SpecificationTest;
 import org.apache.qpid.tests.protocol.v1_0.FrameTransport;
 import org.apache.qpid.tests.protocol.v1_0.Interaction;
-import org.apache.qpid.tests.protocol.SpecificationTest;
 import org.apache.qpid.tests.protocol.v1_0.Utils;
-import org.apache.qpid.tests.protocol.Response;
 import org.apache.qpid.tests.utils.BrokerAdmin;
 import org.apache.qpid.tests.utils.BrokerAdminUsingTestBase;
+import org.apache.qpid.tests.utils.ConfigItem;
 
+@ConfigItem(name = "qpid.tests.mms.messagestore.persistence", value = "false", jvm = true)
 public class MultiTransferTest extends BrokerAdminUsingTestBase
 {
-    private InetSocketAddress _brokerAddress;
-    private String _originalMmsMessageStorePersistence;
 
     @Before
     public void setUp()
     {
-        _originalMmsMessageStorePersistence = System.getProperty("qpid.tests.mms.messagestore.persistence");
-        System.setProperty("qpid.tests.mms.messagestore.persistence", "false");
-
         getBrokerAdmin().createQueue(BrokerAdmin.TEST_QUEUE_NAME);
-        _brokerAddress = getBrokerAdmin().getBrokerAddress(BrokerAdmin.PortType.ANONYMOUS_AMQP);
-    }
-
-    @After
-    public void tearDown()
-    {
-        if (_originalMmsMessageStorePersistence != null)
-        {
-            System.setProperty("qpid.tests.mms.messagestore.persistence", _originalMmsMessageStorePersistence);
-        }
-        else
-        {
-            System.clearProperty("qpid.tests.mms.messagestore.persistence");
-        }
     }
 
     @Test
@@ -93,21 +67,18 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
                           + " but the last transfer frame")
     public void multiTransferMessage() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
-            QpidByteBuffer[] payloads = Utils.splitPayload("testData", 2);
+            QpidByteBuffer[] payloads = Utils.splitPayload(getTestName(), 2);
 
             final UnsignedInteger deliveryId = UnsignedInteger.ZERO;
             final Binary deliveryTag = new Binary("testTransfer".getBytes(UTF_8));
 
             Interaction interaction = transport.newInteraction();
-            Disposition disposition = interaction.negotiateProtocol().consumeResponse()
-                                                 .open().consumeResponse(Open.class)
+            Disposition disposition = interaction.negotiateOpen()
                                                  .begin().consumeResponse(Begin.class)
                                                  .attachRole(Role.SENDER)
                                                  .attachTargetAddress(BrokerAdmin.TEST_QUEUE_NAME)
-                                                 .attachRcvSettleMode(ReceiverSettleMode.SECOND)
-                                                 .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
                                                  .attach().consumeResponse(Attach.class)
                                                  .consumeResponse(Flow.class)
                                                  .transferPayload(payloads[0])
@@ -119,17 +90,20 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
                                                  .transferMore(false)
                                                  .transferPayload(payloads[1])
                                                  .transfer()
-                                                 .consumeResponse()
-                                                 .getLatestResponse(Disposition.class);
+                                                 .consume(Disposition.class, Flow.class);
 
             for (final QpidByteBuffer payload : payloads)
             {
                 payload.dispose();
             }
+
+            interaction.detachEndCloseUnconditionally();
+
             assertThat(disposition.getFirst(), is(equalTo(deliveryId)));
             assertThat(disposition.getLast(), oneOf(null, deliveryId));
-            assertThat(disposition.getSettled(), is(equalTo(false)));
+            assertThat(disposition.getSettled(), is(equalTo(true)));
         }
+        assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME), is(equalTo(getTestName())));
     }
 
     @Test
@@ -139,20 +113,17 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
                           + " message and can only be omitted for continuation transfers.")
     public void multiTransferMessageOmittingOptionalTagAndID() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
-            QpidByteBuffer[] payloads = Utils.splitPayload("testData", 4);
+            QpidByteBuffer[] payloads = Utils.splitPayload(getTestName(), 4);
             final UnsignedInteger deliveryId = UnsignedInteger.ZERO;
             final Binary deliveryTag = new Binary("testTransfer".getBytes(UTF_8));
 
             Interaction interaction = transport.newInteraction();
-            interaction.negotiateProtocol().consumeResponse()
-                       .open().consumeResponse(Open.class)
+            interaction.negotiateOpen()
                        .begin().consumeResponse(Begin.class)
                        .attachRole(Role.SENDER)
                        .attachTargetAddress(BrokerAdmin.TEST_QUEUE_NAME)
-                       .attachRcvSettleMode(ReceiverSettleMode.SECOND)
-                       .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
                        .transferDeliveryId(deliveryId)
@@ -177,54 +148,50 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
                        .transferDeliveryTag(null)
                        .transferMore(false)
                        .transferPayload(payloads[3])
-                       .transfer()
-                       .consumeResponse();
-
-            Disposition disposition = interaction.getLatestResponse(Disposition.class);
+                       .transfer().sync();
 
             for (final QpidByteBuffer payload : payloads)
             {
                 payload.dispose();
             }
+
+            Disposition disposition = interaction.consume(Disposition.class, Flow.class);
+            interaction.detachEndCloseUnconditionally();
+
             assertThat(disposition.getFirst(), is(equalTo(deliveryId)));
             assertThat(disposition.getLast(), oneOf(null, deliveryId));
-            assertThat(disposition.getSettled(), is(equalTo(false)));
+            assertThat(disposition.getSettled(), is(equalTo(true)));
             assertThat(disposition.getState(), is(instanceOf(Accepted.class)));
         }
+        assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME), is(equalTo(getTestName())));
     }
 
-
-    //
-
     @Test
     @SpecificationTest(section = "2.6.14",
             description = "The sender MAY indicate an aborted attempt to deliver a message by setting the abort flag on the last transfer."
                           + "In this case the receiver MUST discard the message data that was transferred prior to the abort.")
     public void abortMultiTransferMessage() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
-            QpidByteBuffer[] payloads = Utils.splitPayload("testData", 2);
+            QpidByteBuffer[] payloads = Utils.splitPayload(getTestName(), 2);
 
             final UnsignedInteger deliveryId = UnsignedInteger.ZERO;
             final Binary deliveryTag = new Binary("testTransfer".getBytes(UTF_8));
 
             Interaction interaction = transport.newInteraction();
-            interaction.negotiateProtocol().consumeResponse()
-                       .open().consumeResponse(Open.class)
+            interaction.negotiateOpen()
                        .begin().consumeResponse(Begin.class)
                        .attachRole(Role.SENDER)
                        .attachTargetAddress(BrokerAdmin.TEST_QUEUE_NAME)
-                       .attachRcvSettleMode(ReceiverSettleMode.SECOND)
-                       .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
                        .transferPayload(payloads[0])
                        .transferDeliveryId(deliveryId)
                        .transferDeliveryTag(deliveryTag)
                        .transferMore(true)
+                       .transferSettled(true)
                        .transfer()
-                       .sync()
                        .transferPayload(null)
                        .transferMore(null)
                        .transferAborted(true)
@@ -234,19 +201,25 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
             {
                 payload.dispose();
             }
-            Response<?> latestResponse = interaction.consumeResponse(new Class<?>[] {null}).getLatestResponse();
-            assertThat(latestResponse, is(nullValue()));
+
+            interaction.detachEndCloseUnconditionally();
         }
+        String secondMessage = getTestName() + "_2";
+        Utils.putMessageOnQueue(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME, secondMessage);
+        assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME), is(equalTo(secondMessage)));
     }
+
     @Test
     @SpecificationTest(section = "2.6.14",
             description = "[...]messages being transferred along different links MAY be interleaved")
     public void multiTransferInterleaved() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        String messageContent1 = getTestName() + "_1";
+        String messageContent2 = getTestName() + "_2";
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
-            QpidByteBuffer[] messagePayload1 = Utils.splitPayload("testData1", 2);
-            QpidByteBuffer[] messagePayload2 = Utils.splitPayload("testData2", 2);
+            QpidByteBuffer[] messagePayload1 = Utils.splitPayload(messageContent1, 2);
+            QpidByteBuffer[] messagePayload2 = Utils.splitPayload(messageContent2, 2);
 
             UnsignedInteger linkHandle1 = UnsignedInteger.ZERO;
             UnsignedInteger linkHandle2 = UnsignedInteger.ONE;
@@ -257,16 +230,13 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
 
             Interaction interaction = transport.newInteraction();
 
-            interaction.negotiateProtocol().consumeResponse()
-                       .open().consumeResponse(Open.class)
+            interaction.negotiateOpen()
                        .begin().consumeResponse(Begin.class)
 
                        .attachName("testLink1")
                        .attachHandle(linkHandle1)
                        .attachRole(Role.SENDER)
                        .attachTargetAddress(BrokerAdmin.TEST_QUEUE_NAME)
-                       .attachRcvSettleMode(ReceiverSettleMode.SECOND)
-                       .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
 
@@ -274,8 +244,6 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
                        .attachHandle(linkHandle2)
                        .attachRole(Role.SENDER)
                        .attachTargetAddress(BrokerAdmin.TEST_QUEUE_NAME)
-                       .attachRcvSettleMode(ReceiverSettleMode.SECOND)
-                       .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
 
@@ -323,30 +291,40 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
             Map<UnsignedInteger, Disposition> dispositionMap = new HashMap<>();
             for (int i = 0; i < 2; i++)
             {
-                Disposition disposition = interaction.consumeResponse(Disposition.class)
-                                                     .getLatestResponse(Disposition.class);
+                Disposition disposition = interaction.consume(Disposition.class, Flow.class);
                 dispositionMap.put(disposition.getFirst(), disposition);
 
                 assertThat(disposition.getLast(), oneOf(null, disposition.getFirst()));
-                assertThat(disposition.getSettled(), is(equalTo(false)));
+                assertThat(disposition.getSettled(), is(equalTo(true)));
                 assertThat(disposition.getState(), is(instanceOf(Accepted.class)));
             }
 
+            interaction.detachEndCloseUnconditionally();
+
             assertThat("Unexpected number of dispositions", dispositionMap.size(), equalTo(2));
             assertThat(dispositionMap.containsKey(deliverId1), is(true));
             assertThat(dispositionMap.containsKey(deliveryId2), is(true));
         }
+        assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME), is(equalTo(messageContent1)));
+        assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME), is(equalTo(messageContent2)));
     }
 
     @Test
     @SpecificationTest(section = "2.6.14",
-            description = "[...]messages transferred along a single link MUST NOT be interleaved")
+            description = "For messages that are too large to fit within the maximum frame size,"
+                          + " additional data MAY be transferred in additional transfer frames by setting"
+                          + " the more flag on all but the last transfer frame."
+                          + " When a message is split up into multiple transfer frames in this manner,"
+                          + " messages being transferred along different links MAY be interleaved."
+                          + " However, messages transferred along a single link MUST NOT be interleaved.")
     public void illegallyInterleavedMultiTransferOnSingleLink() throws Exception
     {
-        try (FrameTransport transport = new FrameTransport(_brokerAddress).connect())
+        String messageContent1 = getTestName() + "_1";
+        String messageContent2 = getTestName() + "_2";
+        try (FrameTransport transport = new FrameTransport(getBrokerAdmin()).connect())
         {
-            QpidByteBuffer[] messagePayload1 = Utils.splitPayload("testData1", 2);
-            QpidByteBuffer[] messagePayload2 = Utils.splitPayload("testData2", 2);
+            QpidByteBuffer[] messagePayload1 = Utils.splitPayload(messageContent1, 2);
+            QpidByteBuffer[] messagePayload2 = Utils.splitPayload(messageContent2, 2);
 
             Binary deliveryTag1 = new Binary("testTransfer1".getBytes(UTF_8));
             Binary deliveryTag2 = new Binary("testTransfer2".getBytes(UTF_8));
@@ -355,14 +333,11 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
 
             Interaction interaction = transport.newInteraction();
 
-            interaction.negotiateProtocol().consumeResponse()
-                       .open().consumeResponse(Open.class)
+            interaction.negotiateOpen()
                        .begin().consumeResponse(Begin.class)
 
                        .attachRole(Role.SENDER)
                        .attachTargetAddress(BrokerAdmin.TEST_QUEUE_NAME)
-                       .attachRcvSettleMode(ReceiverSettleMode.SECOND)
-                       .attachSourceOutcomes(Accepted.ACCEPTED_SYMBOL)
                        .attach().consumeResponse(Attach.class)
                        .consumeResponse(Flow.class)
 
@@ -370,14 +345,28 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
                        .transferDeliveryTag(deliveryTag1)
                        .transferMore(true)
                        .transferPayload(messagePayload1[0])
+                       .transferSettled(true)
                        .transfer()
-                       .sync()
 
                        .transferDeliveryId(deliveryId2)
                        .transferDeliveryTag(deliveryTag2)
                        .transferMore(true)
+                       .transferSettled(true)
                        .transferPayload(messagePayload2[0])
                        .transfer()
+
+                       .transferDeliveryId(deliverId1)
+                       .transferDeliveryTag(deliveryTag1)
+                       .transferMore(false)
+                       .transferPayload(messagePayload1[1])
+                       .transfer()
+
+                       .transferDeliveryId(deliveryId2)
+                       .transferDeliveryTag(deliveryTag2)
+                       .transferMore(false)
+                       .transferPayload(messagePayload2[1])
+                       .transfer()
+
                        .sync();
             for (final QpidByteBuffer payload : messagePayload1)
             {
@@ -388,7 +377,11 @@ public class MultiTransferTest extends BrokerAdminUsingTestBase
                 payload.dispose();
             }
 
-            interaction.consumeResponse(Detach.class, End.class, Close.class);
+            interaction.closeUnconditionally();
         }
+
+        final String controlMessage = getTestName() + "_Control";
+        Utils.putMessageOnQueue(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME, controlMessage);
+        assertThat(Utils.receiveMessage(getBrokerAdmin(), BrokerAdmin.TEST_QUEUE_NAME), is(equalTo(controlMessage)));
     }
 }
