@@ -23,7 +23,7 @@ import static org.hamcrest.CoreMatchers.is;
 import static org.hamcrest.CoreMatchers.not;
 import static org.junit.Assert.assertEquals;
 import static org.junit.Assert.assertNotNull;
-import static org.junit.Assert.assertThat;
+import static org.hamcrest.MatcherAssert.assertThat;
 import static org.junit.Assert.assertTrue;
 import static org.junit.Assert.fail;
 import static org.junit.Assume.assumeThat;
@@ -51,10 +51,13 @@ import javax.jms.Session;
 import javax.jms.TemporaryQueue;
 import javax.jms.TemporaryTopic;
 import javax.jms.TextMessage;
+import javax.naming.NamingException;
 
 import com.fasterxml.jackson.databind.ObjectMapper;
 import com.google.common.collect.Sets;
 import org.junit.Test;
+import org.slf4j.Logger;
+import org.slf4j.LoggerFactory;
 
 import org.apache.qpid.server.logging.EventLogger;
 import org.apache.qpid.server.logging.EventLoggerProvider;
@@ -68,9 +71,6 @@ import org.apache.qpid.server.security.access.config.ObjectProperties;
 import org.apache.qpid.server.security.access.config.ObjectType;
 import org.apache.qpid.server.security.access.config.Rule;
 import org.apache.qpid.server.security.access.config.RuleSet;
-import org.apache.qpid.server.security.access.firewall.FirewallRule;
-import org.apache.qpid.server.security.access.firewall.HostnameFirewallRule;
-import org.apache.qpid.server.security.access.firewall.NetworkFirewallRule;
 import org.apache.qpid.server.security.access.plugins.AclRule;
 import org.apache.qpid.server.security.access.plugins.RuleBasedVirtualHostAccessControlProvider;
 import org.apache.qpid.server.security.access.plugins.RuleOutcome;
@@ -80,6 +80,8 @@ import org.apache.qpid.systests.JmsTestBase;
 
 public class MessagingACLTest extends JmsTestBase
 {
+    private static final Logger LOGGER = LoggerFactory.getLogger(MessagingACLTest.class);
+
     private static final String LINE_SEPARATOR = System.getProperty("line.separator");
     private static final String USER1 = "guest";
     private static final String USER1_PASSWORD = "guest";
@@ -179,6 +181,125 @@ public class MessagingACLTest extends JmsTestBase
         }
     }
 
+    @Test
+    public void testAuthorizationWithConnectionLimit() throws Exception
+    {
+        final int connectionLimit = 2;
+        configureACL(String.format("ACL ALLOW-LOG %s ACCESS VIRTUALHOST connection_limit='%d'",
+                                   USER2,
+                                   connectionLimit));
+
+        final List<Connection> establishedConnections = new ArrayList<>();
+        try
+        {
+            establishConnections(connectionLimit, establishedConnections);
+
+            verifyConnectionEstablishmentFails(connectionLimit);
+
+            establishedConnections.remove(0).close();
+            getConnectionBuilder().setUsername(USER2).setPassword(USER2_PASSWORD).build().close();
+        }
+        finally
+        {
+            closeConnections(establishedConnections);
+        }
+    }
+
+    @Test
+    public void testAuthorizationWithConnectionFrequencyLimit() throws Exception
+    {
+        final int connectionFrequencyLimit = 1;
+        configureACL(String.format("ACL ALLOW-LOG %s ACCESS VIRTUALHOST connection_frequency_limit='%d'",
+                                   USER2,
+                                   connectionFrequencyLimit));
+
+        final List<Connection> establishedConnections = new ArrayList<>();
+        try
+        {
+            establishConnections(connectionFrequencyLimit, establishedConnections);
+
+            verifyConnectionEstablishmentFails(connectionFrequencyLimit);
+
+            establishedConnections.remove(0).close();
+
+            verifyConnectionEstablishmentFails(connectionFrequencyLimit);
+        }
+        finally
+        {
+            closeConnections(establishedConnections);
+        }
+    }
+
+    @Test
+    public void testAuthorizationWithConnectionLimitAndFrequencyLimit() throws Exception
+    {
+        final int connectionFrequencyLimit = 2;
+        final int connectionLimit = 3;
+        configureACL(String.format("ACL ALLOW-LOG %s ACCESS VIRTUALHOST connection_limit='%d' connection_frequency_limit='%d'",
+                                   USER2,
+                                   connectionLimit,
+                                   connectionFrequencyLimit));
+
+        final List<Connection> establishedConnections = new ArrayList<>();
+        try
+        {
+            establishConnections(connectionFrequencyLimit, establishedConnections);
+
+            verifyConnectionEstablishmentFails(connectionFrequencyLimit);
+
+            establishedConnections.remove(0).close();
+
+            verifyConnectionEstablishmentFails(connectionFrequencyLimit);
+        }
+        finally
+        {
+            closeConnections(establishedConnections);
+        }
+    }
+
+    private void establishConnections(final int connectionNumber, final List<Connection> establishedConnections)
+            throws NamingException, JMSException
+    {
+        for (int i = 0; i < connectionNumber; i++)
+        {
+            establishedConnections.add(getConnectionBuilder().setUsername(USER2)
+                                                             .setPassword(USER2_PASSWORD)
+                                                             .setClientId(getTestName() + i)
+                                                             .build());
+        }
+    }
+
+    private void closeConnections(final List<Connection> establishedConnections) throws JMSException
+    {
+        for (Connection c : establishedConnections)
+        {
+            c.close();
+        }
+    }
+
+    private void verifyConnectionEstablishmentFails(final int frequencyLimit) throws NamingException
+    {
+        try
+        {
+            final Connection connection = getConnectionBuilder().setUsername(USER2)
+                                                                .setPassword(USER2_PASSWORD)
+                                                                .setClientId(getTestName() + frequencyLimit)
+                                                                .build();
+            try
+            {
+                fail("Connection creation should fail due to exceeding limit");
+            }
+            finally
+            {
+                connection.close();
+            }
+        }
+        catch (JMSException e)
+        {
+            //pass
+        }
+    }
+
     @Test
     public void testConsumeFromTempQueueSuccess() throws Exception
     {
@@ -227,7 +348,14 @@ public class MessagingACLTest extends JmsTestBase
         }
         finally
         {
-            connection.close();
+            try
+            {
+                connection.close();
+            }
+            catch (Exception e)
+            {
+                LOGGER.error("Unexpected exception on connection close", e);
+            }
         }
     }
 
@@ -603,6 +731,22 @@ public class MessagingACLTest extends JmsTestBase
         }
     }
 
+    @Test
+    public void testAllAllowed() throws Exception
+    {
+        configureACL("ACL ALLOW ALL ALL");
+
+        Connection connection = getConnectionBuilder().setUsername(USER1).setPassword(USER1_PASSWORD).build();
+        try
+        {
+            assertConnection(connection);
+        }
+        finally
+        {
+            connection.close();
+        }
+    }
+
     @Test
     public void testFirewallDeny() throws Exception
     {
@@ -854,21 +998,7 @@ public class MessagingACLTest extends JmsTestBase
                     @Override
                     public Map<ObjectProperties.Property, String> getAttributes()
                     {
-                        Map<ObjectProperties.Property, String> attributes = new HashMap<>(rule.getAction().getProperties().asPropertyMap());
-                        FirewallRule firewallRule = rule.getAclAction().getFirewallRule();
-                        if (firewallRule != null)
-                        {
-                            if (firewallRule instanceof HostnameFirewallRule)
-                            {
-                                attributes.put(ObjectProperties.Property.FROM_HOSTNAME, "127.0.0.1");
-                            }
-                            else if (firewallRule instanceof NetworkFirewallRule)
-                            {
-                                // tests use only 127.0.0.1 at the moment
-                                attributes.put(ObjectProperties.Property.FROM_NETWORK, "127.0.0.1");
-                            }
-                        }
-                        return attributes;
+                        return rule.getAttributes();
                     }
 
                     @Override
