@@ -251,6 +251,12 @@ public class SpawnBrokerAdmin implements BrokerAdmin, Closeable
         return Futures.immediateFuture(null);
     }
 
+    @Override
+    public boolean isAnonymousSupported()
+    {
+        return true;
+    }
+
     @Override
     public boolean isSASLSupported()
     {
@@ -281,6 +287,18 @@ public class SpawnBrokerAdmin implements BrokerAdmin, Closeable
         return true;
     }
 
+    @Override
+    public boolean isPutMessageOnQueueSupported()
+    {
+        return true;
+    }
+
+    @Override
+    public boolean isDeleteQueueSupported()
+    {
+        return true;
+    }
+
     @Override
     public String getValidUsername()
     {
@@ -730,11 +748,17 @@ public class SpawnBrokerAdmin implements BrokerAdmin, Closeable
             classpath = new String(Files.readAllBytes(file.toPath()), UTF_8);
         }
 
+        final ConfigItem[] configItems = (ConfigItem[]) testClass.getAnnotationsByType(ConfigItem.class);
+
         List<String> jvmArguments = new ArrayList<>();
         jvmArguments.add("java");
         jvmArguments.add("-Djava.io.tmpdir=" + escape(System.getProperty("java.io.tmpdir")));
         jvmArguments.add("-Dlogback.configurationFile=default-broker-logback.xml");
         jvmArguments.add("-Dqpid.tests.mms.messagestore.persistence=true");
+        jvmArguments.addAll(Arrays.stream(configItems)
+                                  .filter(ConfigItem::jvm)
+                                  .map(ci -> String.format("-D%s=%s", ci.name(), ci.value()))
+                                  .collect(Collectors.toList()));
         jvmArguments.add("org.apache.qpid.server.Main");
         jvmArguments.add("--store-type");
         jvmArguments.add("JSON");
@@ -752,7 +776,8 @@ public class SpawnBrokerAdmin implements BrokerAdmin, Closeable
               .filter(n -> n.startsWith("qpid."))
               .forEach(n -> context.put(n, System.getProperty(n)));
 
-        context.putAll(Arrays.stream((ConfigItem[]) testClass.getAnnotationsByType(ConfigItem.class))
+        context.putAll(Arrays.stream(configItems)
+                             .filter(i -> !i.jvm())
                              .collect(Collectors.toMap(ConfigItem::name,
                                                        ConfigItem::value,
                                                        (name, value) -> value)));
